| link_obs_with_posterior | R Documentation |
Link posterior estimates with observed data and flag if values are observed or not.
link_obs_with_posterior(posterior, obs, horizon, target_types)
posterior |
A data frame of summarised posterior estimates
as returned by |
obs |
Numeric vector of observed data to link to posterior estimates. |
horizon |
Integer indicating the horizon of unobserved forecasts. If not
specified will be inferred from |
target_types |
A character vector of types (as specified in the |
The input data.frame combined with obs and observed variables.
Functions used for postprocessing of model fits
convert_to_stanfit(),
extract_draws(),
extract_forecast_dates(),
fv_extract_forecast(),
fv_posterior(),
fv_tidy_posterior(),
link_dates_with_posterior(),
plot.fv_posterior(),
print.fv_posterior(),
quantiles_to_long(),
summary.fv_posterior(),
update_voc_label()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.