| plot_default | R Documentation |
Default posterior plot
plot_default(
posterior,
target,
obs = NULL,
forecast_dates = NULL,
central = FALSE,
all_obs = FALSE,
...
)
posterior |
A dataframe of posterior output as produced by
|
target |
A character string indicating which variable to extract from the posterior list. |
obs |
A data frame of observed data as produced by |
forecast_dates |
A data.frame in the format produced by
|
central |
Logical, defaults to FALSE. Should the mean and median
central estimates be plot as dashed and solid lines respectively. Requires
|
all_obs |
Logical, defaults to |
... |
Additional arguments passed to |
A ggplot2 plot.
Plotting functions
add_forecast_dates(),
plot.fv_forecast(),
plot.fv_posterior(),
plot_cases(),
plot_growth(),
plot_pairs(),
plot_posterior(),
plot_rt(),
plot_theme(),
plot_voc_advantage(),
plot_voc_frac(),
save_plots()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.