| plot_posterior | R Documentation |
Plot posterior predictions
plot_posterior(
posterior,
obs = NULL,
forecast_dates = NULL,
central = FALSE,
all_obs = FALSE,
voc_label = "variant of concern"
)
posterior |
A dataframe of posterior output as produced by
|
obs |
A data frame of observed data as produced by |
forecast_dates |
A data.frame in the format produced by
|
central |
Logical, defaults to FALSE. Should the mean and median
central estimates be plot as dashed and solid lines respectively. Requires
|
all_obs |
Logical, defaults to |
voc_label |
Character string giving the name to assign to the variant of concern. Defaults to "variant of concern". |
A named list of all supported package plots with sensible defaults.
Plotting functions
add_forecast_dates(),
plot.fv_forecast(),
plot.fv_posterior(),
plot_cases(),
plot_default(),
plot_growth(),
plot_pairs(),
plot_rt(),
plot_theme(),
plot_voc_advantage(),
plot_voc_frac(),
save_plots()
posterior <- fv_example(strains = 2, type = "posterior")
plot_posterior(posterior)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.