| plot_rt | R Documentation |
Plot the posterior prediction for the reproduction number
plot_rt(posterior, forecast_dates = NULL, central = FALSE, col = NULL)
posterior |
A dataframe of posterior output as produced by
|
forecast_dates |
A data.frame in the format produced by
|
central |
Logical, defaults to FALSE. Should the mean and median
central estimates be plot as dashed and solid lines respectively. Requires
|
col |
A character string denoting the variable to use to stratify the ribbon plot. Defaults to "type" which indicates the data stream. |
A ggplot2 plot.
Plotting functions
add_forecast_dates(),
plot.fv_forecast(),
plot.fv_posterior(),
plot_cases(),
plot_default(),
plot_growth(),
plot_pairs(),
plot_posterior(),
plot_theme(),
plot_voc_advantage(),
plot_voc_frac(),
save_plots()
posterior <- fv_example(strains = 2, type = "posterior")
plot_rt(posterior)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.