| plot_voc_frac | R Documentation |
Plot the population posterior prediction for the fraction of samples with the variant of concern
plot_voc_frac(
posterior,
obs = NULL,
forecast_dates = NULL,
all_obs = FALSE,
central = FALSE,
voc_label = "variant of concern",
logit = TRUE,
...
)
posterior |
A dataframe of posterior output as produced by
|
obs |
A data frame of observed data as produced by |
forecast_dates |
A data.frame in the format produced by
|
all_obs |
Logical, defaults to |
central |
Logical, defaults to FALSE. Should the mean and median
central estimates be plot as dashed and solid lines respectively. Requires
|
voc_label |
Character string giving the name to assign to the variant of concern. Defaults to "variant of concern". |
logit |
Logical, defaults to |
... |
Additional parameters passed to |
A ggplot2 plot.
Plotting functions
add_forecast_dates(),
plot.fv_forecast(),
plot.fv_posterior(),
plot_cases(),
plot_default(),
plot_growth(),
plot_pairs(),
plot_posterior(),
plot_rt(),
plot_theme(),
plot_voc_advantage(),
save_plots()
posterior <- fv_example(strains = 2, type = "posterior")
plot_voc_frac(posterior)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.