| save_plots | R Documentation |
Save plots by name
save_plots(plots, save_path = NULL, type = "png", ...)
plots |
A named list of |
save_path |
A character string indicating where to save plots if required. |
type |
A character string indicating the format to use to save plots. |
... |
Additional arguments passed to |
Plotting functions
add_forecast_dates(),
plot.fv_forecast(),
plot.fv_posterior(),
plot_cases(),
plot_default(),
plot_growth(),
plot_pairs(),
plot_posterior(),
plot_rt(),
plot_theme(),
plot_voc_advantage(),
plot_voc_frac()
posterior <- fv_example(strains = 2, type = "posterior")
p <- plot(posterior, type = "all")
save_plots(p, save_path = tempdir())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.