| update_voc_label | R Documentation |
Assign a custom label to the variant of concern in the
output from fv_tidy_posterior().
update_voc_label(posterior, label, target_label = "VOC")
posterior |
A dataframe of posterior output as produced by
|
label |
Character string indicating the new label to use for the variant of concern. |
target_label |
A character string defaulting to "VOC". Indicates the current label for the variant of concern. |
A list of data frames as returned by 'fv_tidy_posterior() but
with updated labels.
Functions used for postprocessing of model fits
convert_to_stanfit(),
extract_draws(),
extract_forecast_dates(),
fv_extract_forecast(),
fv_posterior(),
fv_tidy_posterior(),
link_dates_with_posterior(),
link_obs_with_posterior(),
plot.fv_posterior(),
print.fv_posterior(),
quantiles_to_long(),
summary.fv_posterior()
p <- fv_example(strains = 2, type = "posterior")
p <- update_voc_label(p, "Delta")
summary(p, type = "cases")
summary(p, type = "model")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.